@@ -241,8 +241,9 @@ class AssignmentValue(object):
         """Returns true if the variable assigned by this object should be allocated."""
         return (self.parent.allocate and 
                 ("allocatable" in self.parent.variable.modifiers or
-                 "pointer" in self.parent.variable.modifiers))        
-
+                 "pointer" in self.parent.variable.modifiers or
+                 (self.parent.variable.D > 0 and ":" in self.parent.variable.dimension)))
+ 
     def copy(self, coderoot, testroot, case):
         """Copies the input files needed for this value to set a variable.
 
